<?php
/**
 * Custom functions that act independently of the theme templates.
 * @package Prelude Lite
 */

 
/**
 * Adds custom classes to the array of body classes.
 * @param array $classes Classes for the body element.
 * @return array
 */
function prelude_lite_body_classes( $classes ) {
	// Adds a class of custom-background-image to sites with a custom background image.
	if ( get_background_image() ) {
		$classes[] = 'custom-background-image';
	}
	
	// Adds a class of group-blog to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}

	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	return $classes;
}
add_filter( 'body_class', 'prelude_lite_body_classes' );


/**
 * Modifies tag cloud widget arguments to have all tags in the widget same font size.
 * @since Prelude Lite 1.0
 * Special thanks to the TwentySixteen theme
 */
function prelude_lite_widget_tag_cloud_args( $args ) {
	$args['largest'] = 0.813;
	$args['smallest'] = 0.813;
	$args['unit'] = 'rem';
	return $args;
}
add_filter( 'widget_tag_cloud_args', 'prelude_lite_widget_tag_cloud_args' );


/**
 * Move the More Link outside from the contents last summary paragraph tag.
 * @since Prelude Lite 1.0
 */
if ( ! function_exists( 'prelude_lite_move_more_link' ) ) :
	function prelude_lite_move_more_link($link) {
			$link = '<p class="more-link-wrapper">'.$link.'</p>';
			return $link;
		}
	add_filter('the_content_more_link', 'prelude_lite_move_more_link');
endif;

/**
 * Filter the except length to the users option setting.
 * @since Prelude Lite 1.0
 */
function prelude_lite_custom_excerpt_length( $length ) {
	$excerpt_length = esc_attr(get_theme_mod( 'excerpt_length', '50' ));
    return $excerpt_length;
}
add_filter( 'excerpt_length', 'prelude_lite_custom_excerpt_length', 999 );

/**
 * Add a more link to the excerpt.
 * @since Prelude Lite 1.0
*/
function prelude_lite_excerpt_more($more) {
       global $post;
	return '&hellip;<p class="more-link-wrapper"><a class="more-link" href="'. esc_url(get_permalink($post->ID)) . '">' . __('Continue Reading', 'prelude-lite') . '</a></p>';
}
add_filter('excerpt_more', 'prelude_lite_excerpt_more');

/**
 * Prevent page scroll after clicking read more to load the full post.
 * @since Prelude Lite 1.0 
 */
if ( ! function_exists( 'prelude_lite_remove_more_link_scroll' ) ) : 
	function prelude_lite_remove_more_link_scroll( $link ) {
		$link = preg_replace( '|#more-[0-9]+|', '', $link );
		return $link;
		}
	add_filter( 'the_content_more_link', 'prelude_lite_remove_more_link_scroll' );
endif;
	
/**
 * Custom comments style
 * @since Prelude Lite 1.0
 */

if (!function_exists('prelude_lite_comment')) {
function prelude_lite_comment($comment, $args, $depth) {
	$GLOBALS['comment'] = $comment; ?>

<li id="comment-<?php echo comment_ID(); ?>">                        
	<div class="comment-wrapper">
		<?php echo get_avatar($comment, 60); ?>
			<div class="comment-info">
				<cite class="fn"><?php echo get_comment_author_link(); ?></cite>   <?php if ( in_array( 'bypostauthor', get_comment_class() ) ) : ?><span class="bypostauthor"><?php esc_html_e('Post Author', 'prelude-lite'); ?></span><?php endif; ?>				                                     		
				<div class="comment-meta"><span class="comment-date"><a href="<?php echo esc_url( get_comment_link( $comment->comment_ID ) ) ?>"><?php echo get_comment_date() . ' at ' . get_comment_time() ?></a>	</span>
				<span class="comment-edit"><?php edit_comment_link( esc_html__( 'Edit Comment', 'prelude-lite' ), '', '' ); ?></span>	
				</div>
			</div>
	
		<div class="comment">
			<?php comment_text(); ?>
		</div>
		<div class="comment-reply"><span class="reply-icon"></span><?php comment_reply_link( array_merge( $args, array('depth' => $depth, 'max_depth' => $args['max_depth']) ) ); ?></div>
	</div>

<?php if ($comment->comment_approved == '0') : ?>
<p><em><?php esc_html_e('Your comment is awaiting moderation.', 'prelude-lite'); ?></em></p>
<?php endif; ?>
<?php 
}
}	




